@@ -10,7 +10,7 @@ parameters.
 import board
 import displayio
 import terminalio
-from adafruit_displayio_layout.widgets.cartesian import Cartesian
+from displayio_cartesian import Cartesian
 
 # Fonts used for the Dial tick labels
 tick_font = terminalio.FONT
@@ -21,7 +21,7 @@ display = board.DISPLAY  # create the display on the PyPortal or Clue (for examp
 
 
 # Create different Cartesian widgets
-my_group = displayio.Group(max_size=10)
+my_group = displayio.Group()
 
 car = Cartesian(
     x=25,
